package xgi.ut.dsl.utl;

import java.io.File;
import java.io.IOException;
import java.text.ParseException;
import java.util.List;

import org.apache.ivy.Ivy;
import org.apache.ivy.core.report.ResolveReport;
import org.apache.ivy.core.settings.IvySettings;
import org.apache.ivy.plugins.resolver.ChainResolver;
import org.apache.ivy.plugins.resolver.IBiblioResolver;

// https://cwiki.apache.org/IVY/programmatic-use-of-ivy.html
public class DependencyUtils {
	
	public static void main(String[]args){
		try{
			resolveDependencies();
		}catch(Throwable t){
			t.printStackTrace();
		}
	}
	
	public static void resolveDependencies() throws ParseException, IOException {
		Ivy ivy = Ivy.newInstance(getIvySettings());

		File dependencyFile = getIvyDependencyFile();
		// resolve the dependencies - Ivy returns a report of the resolution
		ResolveReport resolveReport = ivy.resolve(dependencyFile);

		// check for errors (if any) during resolve
		if (resolveReport.hasError()) {
			System.err.println(getErrorString(resolveReport));
		} else {
			System.out.println("Dependencies in file " + dependencyFile + " were successfully resolved");
		}
	}

	private static String getErrorString(ResolveReport resolveReport) {
		StringBuffer errorMsgs = new StringBuffer();
		List<String> problems = resolveReport.getAllProblemMessages();
		if (problems != null && !problems.isEmpty()) {
			for (String problem : problems) {
				errorMsgs.append(problem);
				errorMsgs.append("\n");
			}
		}
		return errorMsgs.toString();
	}

	private static File getIvyDependencyFile() {
		// file containing the list of dependencies (ex: ivy.xml)
		File dependencyFile = new File(DependencyUtils.class.getResource("/ivy.xml").getFile());
		return dependencyFile;
	}

	private static IvySettings getIvySettings() {
		IvySettings ivySettings = new IvySettings();
		ivySettings.setBaseDir(getLchFolder());
		
		ChainResolver resolver = new ChainResolver();
		resolver.setName("chained");
		IBiblioResolver maven2 = new IBiblioResolver();
		maven2.setM2compatible(true);
		maven2.setName("java-net-maven2");
		maven2.setRoot("http://repo.maven.apache.org/maven2");
		resolver.add(maven2);
		
		ivySettings.setBaseDir(getLchFolder());
		ivySettings.addResolver(resolver);
		ivySettings.setDefaultResolver("chained");
		return ivySettings;
	}

	private static File getLchFolder() {
		// Now let's set the basedir of the ivy settings to some location
		File baseDir = new File(System.getProperty("user.home") + "/.lch");
		if (!baseDir.exists()) {
			baseDir.mkdir();
		}
		return baseDir;
	}
}
