/*
 *   ScenarLang a domain specific language that attempts to make it even easier
 *   to write unit tests with mockito
 *    
 *   Copyright (C) 2012  X. Gillard 
 *   
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *   
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *   
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package xgi.ut.dsl.utl.matching;

import org.mockito.Matchers;
import static org.mockito.Matchers.*;

import xgi.ut.dsl.utl.ReflectionUtil;


public class MetaAnyMatcher implements MetaMatcher {
	private Class<?> clazz;

	public MetaAnyMatcher(Class<?> clazz) {
		super();
		this.clazz = clazz;
	}

	@Override
	public Class<?> getDeclaredType() {
		return clazz;
	}

	@Override
	public Object getActualValue() {
		return null;
	}

	@Override
	public Object match() {
		Class<?> unwrapped = ReflectionUtil.unwrap(getDeclaredType());
		if(char.class.equals(unwrapped)){
			return anyChar();
		}
		if(byte.class.equals(unwrapped)){
			return anyByte();
		}
		if(short.class.equals(unwrapped)){
			return anyShort();
		}
		if(int.class.equals(unwrapped)){
			return anyInt();
		}
		if(long.class.equals(unwrapped)){
			return anyLong();
		}
		if(float.class.equals(unwrapped)){
			return anyFloat();
		}
		if(double.class.equals(unwrapped)){
			return anyDouble();
		}
		if(boolean.class.equals(unwrapped)){
			return anyBoolean();
		}
		return Matchers.any(clazz);
	}

	@Override
	public void setDeclaredType(Class<?> clazz) {
		this.clazz = clazz;
	}

	@Override
	public void setActualValue(Object o) {
		// IGNORE
	}
}
